<?php

namespace SmartMailer\Forms;

require_once __DIR__ . '/FormFactory.php';
require_once SMARTMAILER_ROOT_DIR . '/src/SmartMailerFunctions.php';

use Nette\Forms\Form;

class CF7 {
	public function createForm(): Form {
		$form      = ( new \SmartMailer\Forms\FormFactory() )->create();
		$cf7_forms = \SmartMailerFunctions::get_cf7_forms();
		$defaults  = array();

		foreach ( $cf7_forms as $cf7_form ) {
			$container = $form->addContainer( 'tab' . $cf7_form->ID );
			$cf7_frm   = \WPCF7_ContactForm::get_instance( $cf7_form );

			if ( null === $cf7_frm ) {
				continue;
			}

			$cf7_form_fields                   = $cf7_frm->scan_form_tags();
			$defaults[ 'tab' . $cf7_form->ID ] = get_option( 'sm_cf7_' . $cf7_form->ID, array() );

			foreach ( $cf7_form_fields as $cf_form_field ) {
				if ( 'submit' !== $cf_form_field['type'] ) {
					$container->addText( str_ireplace( '-', '', sanitize_title( $cf_form_field['name'] ) ), $cf_form_field['name'] )->setRequired( false );
				}
			}
		}

		$form->addSubmit( 'saveCF7Settings' );

		$form->setDefaults( $defaults );

		if ( $form->isSuccess() ) {
			$values = $form->getValues( true );
			foreach ( $cf7_forms as $cf7_form ) {
				$selector = 'tab' . $cf7_form->ID;
				update_option( 'sm_cf7_' . $cf7_form->ID, $values[ $selector ], 'no' );
			}

			wp_safe_redirect(
				add_query_arg(
					array(
						'page' => 'smartmailer-cf7-settings',
						'smu'  => 1,
					),
					get_admin_url() . 'admin.php'
				)
			);
		}

		return $form;
	}
}
