<?php
// https://smartmailer.cz/docs/

class Api
{
    /**
     * @var string|null
     */
    private $accessToken = null;
    private $url = 'smartmailer.cz';
    // private $url = 'dev.smartmailer.cz';


    /**
     * @param string $accessToken
     * @throws Exception
     */
    public function __construct($accessToken)
    {
        $this->setAccessToken($accessToken);
    }


    /**
     * @param string $token
     * @throws Exception
     */
    public function setAccessToken($token)
    {
        if ($token === '') {
            throw new Exception('Invalid token');
        }
        $this->accessToken = $token;
    }


    public function checkToken()
    {
        $ch = curl_init('https://' . $this->url . '/api/v1/check/token');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $data = curl_exec($ch);
        $info = curl_getinfo($ch);

        curl_close($ch);

        return $info;
    }


    /**
     * @param string $uuid
     * @return bool|string
     * @throws Exception
     */
    public function deleteContact($uuid)
    {
        if (!$uuid) {
            throw new Exception('Invalid contact UUID');
        }

        $ch = curl_init('https://' . $this->url . '/api/v1/contacts/' . $uuid);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $data = curl_exec($ch);
        $info = curl_getinfo($ch);

        curl_close($ch);

        return $info;
    }


    /**
     * @param array  $contacts
     * @param string $addressBookUuid
     * @return bool|string
     */
    public function deleteContacts(array $contacts, $addressBookUuid)
    {
        $ch = curl_init('https://' . $this->url . '/api/v1/addressbook/' . $addressBookUuid . '/contacts');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $json = json_encode($contacts);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

        $data = curl_exec($ch);
        $info = curl_getinfo($ch);

        curl_close($ch);

        return $info;
    }


    /**
     * @throws JsonException
     */
    public function insertContacts($addressBookUuid, array $contacts)
    {
        if (!$addressBookUuid) {
            throw new Exception('Invalid AddressBook UUID');
        }

        if (empty($contacts)) {
            throw new Exception('No contacts');
        }

        $ch = curl_init('https://' . $this->url . '/api/v1/addressbook/' . $addressBookUuid . '/contacts');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, 1);

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $json = json_encode($contacts);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

        $data = curl_exec($ch);

        curl_close($ch);
        return $data;
    }
}
