<?php
require_once SMARTMAILER_ROOT_DIR . '/src/SmartMailerFunctions.php';

// WordPress hook - user register.
add_action(
	'user_register',
	function ( $user_id ) {
		if ( get_option( 'smartmailer_int_wordpress', false ) ) {
			$user = get_user_by( 'ID', $user_id );
			if ( $user instanceof WP_User ) {
				$data = apply_filters( 'smartmailer_user_fields', SmartMailerFunctions::getWPUserFields() );

				foreach ( $data as $data_key => $data_field ) {
					$data[ $data_key ]['value'] = $user->get( $data_field['key'] );
				}

				SmartMailerFunctions::sendToSmartMailer( $data );
			}
		}
	},
	10,
	1
);

// WordPress hook - comment
add_action(
	'comment_post',
	function ( $comment_id, $comment_approved ) {
		if ( get_option( 'smartmailer_int_wordpress', false ) ) {
			$comment = get_comment( $comment_id );
			if ( $comment instanceof WP_Comment ) {
				$name = explode( ' ', $comment->comment_author );
				$data = array();

				$data['FNAME']['value'] = $name[0];
				$data['LNAME']['value'] = $name[1] ?? null;
				$data['EMAIL']['value'] = $comment->comment_author_email;

				SmartMailerFunctions::sendToSmartMailer( $data );
			}
		}
	},
	10,
	2
);

// WooCommerce hook - new order
add_action(
	'woocommerce_new_order',
	function ( $order_id ) {
		if ( get_option( 'smartmailer_int_woocommerce', false ) ) {
			$order        = wc_get_order( $order_id );
			$customerData = $order->get_base_data()['billing'];
			$data         = apply_filters( 'smartmailer_wc_fields', SmartMailerFunctions::getWCFields() );

			foreach ( $data as $dataKey => $dataField ) {
				$keyExists = array_key_exists( $dataField['key'], $customerData );
				if ( $keyExists ) {
					$data[ $dataKey ]['value'] = $customerData[ $dataField['key'] ];
				}
			}

			SmartMailerFunctions::sendToSmartMailer( $data );
		}
	},
	10,
	1
);

// Contact Form 7 hook - send form
add_filter(
	'wpcf7_before_send_mail',
	function ( $contact_form, $abort, $submission ) {
		if ( get_option( 'smartmailer_int_contactform7', false ) ) {
			$data = apply_filters( 'smartmailer_cf7_fields', SmartMailerFunctions::getCF7Fields() );

			foreach ( $data as $dataKey => $dataField ) {
				$value = $submission->get_posted_data( $dataField['key'] );
				if ( ! is_null( $value ) ) {
					$data[ $dataKey ]['value'] = $value;
				}
			}

			SmartMailerFunctions::sendToSmartMailer( $data );
		}

		return $contact_form;
	},
	10,
	3
);

// WPForms hook - send form
add_action(
	'wpforms_process_complete',
	function ( $fields, $entry, $form_data, $entry_id ) {
		$form_id   = (int) $form_data['id'];
		$sm_fields = array();

		if ( get_option( 'smartmailer_int_wpforms', false ) ) {
			$data        = apply_filters( 'smartmailer_wpforms_fields', SmartMailerFunctions::getWPFormsFields( $form_id ) );
			$result_data = array();

			foreach ( $fields as $field ) {
				$sm_fields[ str_ireplace( '-', '', sanitize_title( $field['name'] ) ) ] = $field['value'];
			}

			foreach ( $data as $data_key => $data_field ) {
				if ( array_key_exists( $data_field['key'], $sm_fields ) ) {
					$result_data[ $data_key ]['key']   = $data_field['key'];
					$result_data[ $data_key ]['value'] = $sm_fields[ $data_field['key'] ];
				}
			}

			SmartMailerFunctions::sendToSmartMailer( $result_data );
		}
	},
	10,
	4
);
